pitchtools.set_written_pitch_of_pitched_components_in_expr
==========================================================

.. autofunction:: abjad.tools.pitchtools.set_written_pitch_of_pitched_components_in_expr.set_written_pitch_of_pitched_components_in_expr
